summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/tilereg-dgn.cc
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2012-01-25 06:38:59 +0100
committerAdam Borowski <kilobyte@angband.pl>2012-01-25 06:38:59 +0100
commit6871f025b85565396327488fb4e9380349f0fb84 (patch)
tree42a867c21181dc81aaf9266a897761baa25b9c70 /crawl-ref/source/tilereg-dgn.cc
parent97e9b58bb1f84589e00f01585d8ca91f2e0a212e (diff)
downloadcrawl-ref-6871f025b85565396327488fb4e9380349f0fb84.tar.gz
crawl-ref-6871f025b85565396327488fb4e9380349f0fb84.zip
Get rid of USisms in spelling of -ll- and -tt-.
This mostly reverts 78d8ab06 which replaced Commonwealth "targetting" with US "targeting", although there's also "cancelLing", "levelLing", "travelLing".
Diffstat (limited to 'crawl-ref/source/tilereg-dgn.cc')
-rw-r--r--crawl-ref/source/tilereg-dgn.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/crawl-ref/source/tilereg-dgn.cc b/crawl-ref/source/tilereg-dgn.cc
index be111a2369..7d82d7e156 100644
--- a/crawl-ref/source/tilereg-dgn.cc
+++ b/crawl-ref/source/tilereg-dgn.cc
@@ -354,11 +354,11 @@ void DungeonRegion::on_resize()
// FIXME: If the player is targeted, the game asks the player to target
// something with the mouse, then targets the player anyway and treats
// mouse click as if it hadn't come during targeting (moves the player
// to the clicked cell, whatever).
-static void _add_targeting_commands(const coord_def& pos)
+static void _add_targetting_commands(const coord_def& pos)
{
// Force targeting cursor back onto center to start off on a clean
// slate.
macro_buf_add_cmd(CMD_TARGET_FIND_YOU);
@@ -391,7 +391,7 @@ static const bool _is_appropriate_spell(spell_type spell,
ASSERT(is_valid_spell(spell));
const unsigned int flags = get_spell_flags(spell);
- const bool targeted = flags & SPFLAG_TARGETING_MASK;
+ const bool targeted = flags & SPFLAG_TARGETTING_MASK;
// We don't handle grid targeted spells yet.
if (flags & SPFLAG_GRID)
@@ -544,13 +544,13 @@ static bool _evoke_item_on_target(actor* target)
macro_buf_add_cmd(CMD_EVOKE);
macro_buf_add(index_to_letter(item->link)); // Inventory letter.
- _add_targeting_commands(target->pos());
+ _add_targetting_commands(target->pos());
return (true);
}
static bool _spell_in_range(spell_type spell, actor* target)
{
- if (!(get_spell_flags(spell) & SPFLAG_TARGETING_MASK))
+ if (!(get_spell_flags(spell) & SPFLAG_TARGETTING_MASK))
return (true);
int range = calc_spell_range(spell);
@@ -646,8 +646,8 @@ static bool _cast_spell_on_target(actor* target)
if (item_slot != -1)
macro_buf_add(item_slot);
- if (get_spell_flags(spell) & SPFLAG_TARGETING_MASK)
- _add_targeting_commands(target->pos());
+ if (get_spell_flags(spell) & SPFLAG_TARGETTING_MASK)
+ _add_targetting_commands(target->pos());
return (true);
}
@@ -690,7 +690,7 @@ static bool _handle_distant_monster(monster* mon, unsigned char mod)
&& !mon->wont_attack()))
{
macro_buf_add_cmd(CMD_FIRE);
- _add_targeting_commands(mon->pos());
+ _add_targetting_commands(mon->pos());
return (true);
}
@@ -706,7 +706,7 @@ static bool _handle_distant_monster(monster* mon, unsigned char mod)
if (dist > 2 && weapon && reach_range(weapon_reach(*weapon)) >= dist)
{
macro_buf_add_cmd(CMD_EVOKE_WIELDED);
- _add_targeting_commands(mon->pos());
+ _add_targetting_commands(mon->pos());
return (true);
}
}
@@ -354,11 +354,11 @@ void DungeonRegion::on_resize()
// FIXME: If the player is targeted, the game asks the player to target
// something with the mouse, then targets the player anyway and treats
-// mouse click as if it hadn't come during targeting (moves the player
+// mouse click as if it hadn't come during targetting (moves the player
// to the clicked cell, whatever).
@@ -354,11 +354,11 @@ void DungeonRegion::on_resize()
{
- // Force targeting cursor back onto center to start off on a clean
+ // Force targetting cursor back onto center to start off on a clean
// slate.
macro_buf_add_cmd(CMD_TARGET_FIND_YOU);